<?php

namespace App\Controller;

use App\Entity\Branch;
use App\Entity\Message;
use App\Form\CreateMessageType;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

#[Route('/branches')]
final class BranchController extends AbstractController
{
    public function __construct(private readonly EntityManagerInterface $entityManager)
    {
    }

    #[Route('/{id}', name: 'branch', methods: ['GET'])]
    public function index(Branch $branch): Response
    {
        return $this->render('branch/show.html.twig', [
            'branch' => $branch,
            'create_message_form' => $this->createForm(CreateMessageType::class),
        ]);
    }

    #[Route('/{id}', name: 'branch.create', methods: ['POST'])]
    public function create(Branch $branch, Request $request): Response
    {
        $message = new Message();
        $form = $this->createForm(CreateMessageType::class, $message);

        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid()) {
            $message->setBranch($branch);

            $this->entityManager->persist($message);
            $this->entityManager->flush();
        }

        return $this->redirectToRoute('branch', ['id' => $branch->getId()]);
    }
}
